@@ -37,7 +37,7 @@ typedef int (*LZO_FUNC)();
 LZO_FUNC _gnutls_lzo1x_decompress_safe = NULL;
 LZO_FUNC _gnutls_lzo1x_1_compress = NULL;
 
-/* The flag d is the direction (compressed, decompress). Non zero is
+/* The flag d is the direction (compress, decompress). Non zero is
  * decompress.
  */
 GNUTLS_COMP_HANDLE _gnutls_comp_init( gnutls_compression_method method, int d)
@@ -54,8 +54,8 @@ int err;
 	ret->algo = method;
 	ret->handle = NULL;
 
-#ifdef HAVE_LIBZ
 	switch( method) {
+#ifdef HAVE_LIBZ
 	    case GNUTLS_COMP_ZLIB: {
 		int window_bits, mem_level;
 		int comp_level;
@@ -68,7 +68,7 @@ int err;
 		ret->handle = gnutls_malloc( sizeof( z_stream));
 		if (ret->handle==NULL) {
 			gnutls_assert();
-			return NULL;
+			goto cleanup_ret;
 		}
 		
 		zhandle = ret->handle;
@@ -86,30 +86,28 @@ int err;
 		}
 		if (err!=Z_OK) {
 			gnutls_assert();
-			gnutls_free( ret);
 			gnutls_free( ret->handle);
-			return NULL;
+			goto cleanup_ret;
 		}
 		break;
 	    }
+#endif
 	    case GNUTLS_COMP_LZO:
 	        if (d) /* LZO does not use memory on decompressor */
-	           ret->handle = NULL;
+	        { /* ret->handle = NULL; */ }
 	        else {
   		   ret->handle = gnutls_malloc( LZO1X_1_MEM_COMPRESS);
   		  
  		   if (ret->handle==NULL) {
 			gnutls_assert();
+			cleanup_ret:
+			gnutls_free(ret);
 			return NULL;
 		   }
 		}
 		
 		break;
-
-	    default:
-	    	break;
 	}
-#endif
 	return ret;
 }
 
@@ -118,8 +116,8 @@ int err;
 
 	if (handle!=NULL) {
 		switch( handle->algo) {
-			case GNUTLS_COMP_LZO:
-				break;
+			/* case GNUTLS_COMP_LZO:
+				break; */
 #ifdef HAVE_LIBZ
 			case GNUTLS_COMP_ZLIB:
 				if (d)
@@ -128,15 +126,11 @@ int err;
 					err = deflateEnd( handle->handle);
 				break;
 #endif
-			default:
-				break;
 		}
 		gnutls_free( handle->handle);
 		gnutls_free( handle);
 
 	}
-
-	return;
 }
 
 /* These functions are memory consuming 
@@ -160,22 +154,20 @@ int err;
 				return GNUTLS_E_COMPRESSION_FAILED;
 			
 			size = plain_size + plain_size / 64 + 16 + 3;
-			*compressed=NULL;
-
 			*compressed = gnutls_malloc(size);
 			if (*compressed==NULL) {
 				gnutls_assert();
 				return GNUTLS_E_MEMORY_ERROR;
 			}
 
-		 	err = _gnutls_lzo1x_1_compress( plain, plain_size, *compressed,
-		 	        &out_len, handle->handle);
+			err = _gnutls_lzo1x_1_compress( plain, plain_size, *compressed,
+			        &out_len, handle->handle);
 
-		 	if (err!=LZO_E_OK) {
-		 		gnutls_assert();
-		 		gnutls_free( *compressed);
-		 		return GNUTLS_E_COMPRESSION_FAILED;
-		 	}
+			if (err!=LZO_E_OK) {
+				gnutls_assert();
+				gnutls_free( *compressed); *compressed = NULL;
+				return GNUTLS_E_COMPRESSION_FAILED;
+			}
 
 			compressed_size = out_len;
 			break;
@@ -186,8 +178,6 @@ int err;
 			z_stream *zhandle;
 			
 			size = (plain_size+plain_size)+10;
-			*compressed=NULL;
-
 			*compressed = gnutls_malloc(size);
 			if (*compressed==NULL) {
 				gnutls_assert();
@@ -201,13 +191,13 @@ int err;
 			zhandle->next_out = (Bytef*) *compressed;
 			zhandle->avail_out = size;
 		
-		 	err = deflate( zhandle, Z_SYNC_FLUSH);
+			err = deflate( zhandle, Z_SYNC_FLUSH);
 
-		 	if (err!=Z_OK || zhandle->avail_in != 0) {
-		 		gnutls_assert();
-		 		gnutls_free( *compressed);
-		 		return GNUTLS_E_COMPRESSION_FAILED;
-		 	}
+			if (err!=Z_OK || zhandle->avail_in != 0) {
+				gnutls_assert();
+				gnutls_free( *compressed); *compressed = NULL;
+				return GNUTLS_E_COMPRESSION_FAILED;
+			}
 
 			compressed_size = size - zhandle->avail_out;
 			break;
@@ -223,7 +213,7 @@ int err;
 #endif
 
 	if ((size_t)compressed_size > max_comp_size) {
-		gnutls_free(*compressed);
+		gnutls_free(*compressed); *compressed = NULL;
 		return GNUTLS_E_COMPRESSION_FAILED;
 	}
 
@@ -274,7 +264,7 @@ int cur_pos;
 
 		 	if (err!=LZO_E_OK) {
 		 		gnutls_assert();
-		 		gnutls_free( *plain);
+		 		gnutls_free( *plain); *plain = NULL;
 		 		return GNUTLS_E_DECOMPRESSION_FAILED;
 		 	}
 
@@ -309,16 +299,16 @@ int cur_pos;
 				zhandle->next_out = (Bytef*) (*plain + cur_pos);
 				zhandle->avail_out = out_size - cur_pos;
 
-			 	err = inflate( zhandle, Z_SYNC_FLUSH);
+				err = inflate( zhandle, Z_SYNC_FLUSH);
 			 	
-			 	cur_pos = out_size - zhandle->avail_out;
+				cur_pos = out_size - zhandle->avail_out;
 
 			} while( (err==Z_BUF_ERROR && zhandle->avail_out==0 && out_size < max_record_size) 
 				|| ( err==Z_OK && zhandle->avail_in != 0));
 
 		 	if (err!=Z_OK) {
 		 		gnutls_assert();
-		 		gnutls_free( *plain);
+		 		gnutls_free( *plain); *plain = NULL;
 		 		return GNUTLS_E_DECOMPRESSION_FAILED;
 		 	}
 
@@ -333,7 +323,7 @@ int cur_pos;
 
 	if ((size_t)plain_size > max_record_size) {
 		gnutls_assert();
-		gnutls_free( *plain);
+		gnutls_free( *plain); *plain = NULL;
 		return GNUTLS_E_DECOMPRESSION_FAILED;
 	}
 
