@@ -67,6 +67,8 @@ void gnutls_x509_privkey_deinit(gnutls_x509_privkey key)
 {
 int i;
 
+	if (!key) return;
+
 	for (i = 0; i < key->params_size; i++) {
 		_gnutls_mpi_release( &key->params[i]);
 	}
@@ -465,7 +467,7 @@ int gnutls_x509_privkey_get_pk_algorithm( gnutls_x509_privkey key)
   *
   **/
 int gnutls_x509_privkey_export( gnutls_x509_privkey key,
-	gnutls_x509_crt_fmt format, unsigned char* output_data, int* output_data_size)
+	gnutls_x509_crt_fmt format, unsigned char* output_data, size_t* output_data_size)
 {
 	char * msg;
 		
@@ -804,7 +806,7 @@ static int _encode_rsa( ASN1_TYPE* c2, GNUTLS_MPI* params)
   *
   **/
 int gnutls_x509_privkey_generate( gnutls_x509_privkey key, gnutls_pk_algorithm algo,
-	int bits, unsigned int flags)
+	unsigned int bits, unsigned int flags)
 {
 int ret;
 
@@ -1073,7 +1075,7 @@ opaque algo = GNUTLS_PK_DSA;
   *
   **/
 int gnutls_x509_privkey_get_key_id( gnutls_x509_privkey key, unsigned int flags,
-	unsigned char* output_data, int* output_data_size)
+	unsigned char* output_data, size_t* output_data_size)
 {
 		
 	if (key->pk_algorithm == GNUTLS_PK_RSA)
